@@ -154,6 +154,23 @@ def test_is_bogus():
     for ip, expected in (
         ('210.230.128.224', False),
         ('210.153.84.0', True),
+
+        # Updated at 2010/12/1
+        ('111.86.142.128', False), # 111.86.142.128/27
+        ('111.86.142.160', False), # 111.86.142.160/27
+        ('111.86.142.192', False), # 111.86.142.191/27
+        ('111.86.142.224', False), # 111.86.142.224/27
+        ('111.86.143.0',   False), # 111.86.143.0/27
+        ('111.86.143.32',  False), # 111.86.143.32/27
+
+        # will be added in Jan 2011
+        ('111.86.147.32',  True), # 111.86.147.32/27
+        ('111.86.147.64',  True), # 111.86.147.64/27
+        ('111.86.147.96',  True), # 111.86.147.96/27
+        ('111.86.147.128', True), # 111.86.147.128/27
+        ('111.86.147.160', True), # 111.86.147.160/27
+        ('111.86.147.192', True), # 111.86.147.192/27
+        ('111.86.147.224', True), # 111.86.147.224/27
         ):
         yield func, ip, expected
 
